;-------------------------------------------------------------------------------
; Uninstall functions
;
;   Copyright (C) 2008, 2009 Alesc
;   This program is free software: you can redistribute it and/or modify
;   it under the terms of the GNU General Public License.
;-------------------------------------------------------------------------------

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
#WinActivateForce
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
#SingleInstance force

if InitHotsUninstall() = HOT_ERR
    return

CreateUninstallGUI()

return
;---------------------------------------
; InitHotsUninstall
;
; Arguments: None
;
; Returns:
;   nothing
;
; Description:
;   Initializes menu and all global 
;   variables needed
;
; Important globals initialized:
;   PROGRAM_INSTALL_NAME
;---------------------------------------
InitHotsUninstall()
{
    global

    FIRM_NAME = Alesc Freeware
    TITLE = Hots_Uninstall
    VERSION = 0.5
    PROGRAM_INSTALL_NAME = Hots
    PROG_REG_KEY = SOFTWARE\%FIRM_NAME%\%PROGRAM_INSTALL_NAME%

    uninstalll_GUIhandle = 1
    about_GUIhandle = 2

    ; custom tray menu
    menu, tray, NoStandard
    menu, tray, add, Reload, menuHandler
    menu, tray, add
    menu, tray, add, About..., menuHandler
    menu, tray, add
    menu, tray, add, Exit, menuHandler
    menu, tray, tip, %TITLE% %VERSION%

    if ((SETUP_TMP_PATH := InitCORElib(TITLE)) = HOT_ERR)
        return %HOT_ERR%

    if Unpack() = HOT_ERR
        return %HOT_ERR%

    if GetInstallInfo(1) = HOT_ERR
        return %HOT_ERR%

    return %HOT_OK%
}
;---------------------------------------
; KillProgram
;
; Arguments: pid_filename - filename holding pid of running program
;
; Returns:
;   HOT_OK/HOT_ERR
;
; Description:
;   Finds if program beeing deinstalled is running
;   and close it. Filename holding the pid is removed.
;---------------------------------------
KillProgram(pid_filename)
{
    global
    local pid

    IfNotExist, %pid_filename%
        return %HOT_OK%

    FileRead, pid, %pid_filename%
    if ErrorLevel
    {
        Report("Error", "Can not read pid file [" . pid_filename . "].")
        return %HOT_ERR%
    }

    Process, Close, %pid%,
    if ErrorLevel = 0
    {
        Report("Error", "Failed to terminate program with pid:[" . pid . "].")
        return %HOT_ERR%
    }

    FileDelete, %pid_filename%

    return %HOT_OK%
}
;---------------------------------------
; Uninstall
;
; Arguments: None
;
; Returns:
;   HOT_OK/HOT_ERR
;
; Description:
;   Is called from gui when uninstall is started.
;   Deletes file from path got from win.registry nad
;   deletes wi.registry values for hots.
;
; Important globals initialized:
;   SETUP_ACTIONS
;---------------------------------------
Uninstall()
{
    global

    SETUP_ACTIONS = 9
    CURRENT_ACTION = 0

    KillProgram(PROGRAM_INSTALL_NAME . "_pid.dat")
    ; remove sub dirs
    UpdateProgressText("Deleting " . SetupPath . "\log")
    FileRemoveDir, %SetupPath%\log, 1
    UpdateProgressBar()

    UpdateProgressText("Deleting " . SetupPath . "\resources")
    FileRemoveDir, %SetupPath%\resources, 1
    UpdateProgressBar()
    ; remove pspad jscripts
    GetPSPPaths()
    UpdateProgressText("Installing hots.js")
    FileDelete, %PSP_JSCRIPTS_PATH%\hots.js
    UpdateProgressBar()

    UpdateProgressText("Installing hots_core.js")
    FileDelete, %PSP_JSCRIPTS_PATH%\hots_core.js
    UpdateProgressBar()

    UpdateProgressText("Installing hots_ctag.js")
    FileDelete, %PSP_JSCRIPTS_PATH%\hots_ctag.js
    UpdateProgressBar()
    ; remove core files
    UpdateProgressText("Deleting " . PROGRAM_INSTALL_NAME)
    FileDelete, %SetupPath%\%PROGRAM_INSTALL_NAME%.exe
    UpdateProgressBar()

    UpdateProgressText("Deleting hots_help.html")
    FileDelete, %SetupPath%\hots_help.html
    UpdateProgressBar()

    UpdateProgressText("Deleting COPYING.txt")
    FileDelete, %SetupPath%\COPYING.txt
    UpdateProgressBar()

    ; remove root dir
    UpdateProgressText("Deleting " . SetupPath)
    FileRemoveDir, %SetupPath%, 1
    UpdateProgressBar()
    ; remove link and group
    UpdateProgressText("Deleting program group and link")
    RegReadEx("HKEY_CURRENT_USER",PROG_REG_KEY, "ProgramGroup", ProgramGroupCreated)
    RegReadEx("HKEY_CURRENT_USER",PROG_REG_KEY, "DesktopLink", DeskLinkCreated)
    if ProgramGroupCreated = 1
        FileRemoveDir, %A_Programs%\%PROGRAM_INSTALL_NAME%, 1
    if DeskLinkCreated = 1
        FileDelete, %A_Desktop%\%PROGRAM_INSTALL_NAME%.lnk
    UpdateProgressBar()
    ; remove user data
    UpdateProgressText("Deleting user's data")
    FileRemoveDir, %A_AppData%\%PROGRAM_INSTALL_NAME%, 1
    UpdateProgressBar()
    ; remove registry
    UpdateProgressText("Deleting " . PROG_REG_KEY)
    if RegDeleteEx("HKEY_CURRENT_USER", PROG_REG_KEY) = HOT_ERR
        return %HOT_ERR%
    UpdateProgressBar()

    return %HOT_OK%
}
;---------------------------------------
; Unpack
;
; Arguments: None
;
; Returns:
;   HOT_OK/HOT_ERR
;
; Description:
;   Creates/installs needed dirs/files by uninstall.
;---------------------------------------
Unpack()
{
    global

    if FileCreateDirEx(SETUP_TMP_PATH . "\resources") = HOT_ERR
        return %HOT_ERR%
    FileInstall, .\resources\hots_about.jpg, %SETUP_TMP_PATH%\resources\hots_about.jpg, 1
    FileInstall, .\resources\setup_stamp.gif, %SETUP_TMP_PATH%\resources\setup_stamp.gif, 1
    FileInstall, .\resources\setup_title.gif, %SETUP_TMP_PATH%\resources\setup_title.gif, 1
}

menuHandler:
if (A_ThisMenuItem = "Reload")
{
    DeinitCORElib(TITLE)
    Reload
}
else if (A_ThisMenuItem = "About...")
{
    AboutSetup()

}
else if (A_ThisMenuItem = "Exit")
{
    DeinitCORElib(TITLE)
    ExitApp
}
return
;-------------------------------------------------------------------------------
; Includes
;-------------------------------------------------------------------------------
#Include %A_ScriptDir%\includes\core_lib.ahk
#Include %A_ScriptDir%\includes\debug_lib.ahk
#Include %A_ScriptDir%\includes\setup_core.ahk
#Include %A_ScriptDir%\includes\uninstall_gui.ahk
#include %A_ScriptDir%\includes\psp_lib.ahk
